reincarnatie = [(0, ["I", "bIIIM7"]),
		(8, ["Vm", "bVIIM"]),
		(12, ["I", "bIIIM7"]),
		(16, ["Vm", "bVIIM"]),
		(20, ["bIIIM", "bIIIM", "bVIIM", "bVIIM", "IV", "IV"]),
		(21, ["Im", "Vm"]),
		(22, ["bIIIM", "bIIIM", "bVIIM", "bVIIM", "IV", "IV"]),
		(23, ["Im", "Vm"]),
		(24, 'R')]

fietsen_intro = [
	   (0, ["I5", "bIII5"]),
	   (3, ["IV5", "bIII5"]),
	   (4, ["I5", "bIII5"]),
	   (7, ["IV5", "bIII5"]),
	   (8, ["I5", "bIII5"]),
	   (11, ["IV5", "bIII5"]),
	   (12, ["I5", "bIII5"]),
	   (15, ["IV5", "V7#9"]),
	   (16, 'R')]

fietsen_couplet = [(0, ["I", "IV", "#Vdom7", "V7"]),
		   (1, 'R')]

